@@ -616,15 +616,18 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'GRUB_GFXMODE': self.gfxmode,
             'GRUB_TERMINAL': '"{0}"'.format(self.terminal)
         }
+        grub_final_cmdline = re.sub(
+            r'root=.* |root=.*$', '', self.cmdline
+        ).strip()
         if self.displayname:
             grub_default_entries['GRUB_DISTRIBUTOR'] = '"{0}"'.format(
                 self.displayname
             )
         if self.timeout_style:
             grub_default_entries['GRUB_TIMEOUT_STYLE'] = self.timeout_style
-        if self.cmdline:
+        if grub_final_cmdline:
             grub_default_entries['GRUB_CMDLINE_LINUX_DEFAULT'] = '"{0}"'.format(
-                re.sub(r'root=.* |root=.*$', '', self.cmdline).strip()
+                grub_final_cmdline
             )
         if self.terminal and 'serial' in self.terminal and \
            self.serial_line_setup:
@@ -813,19 +816,28 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 early_boot_script, mbrid
             )
         module_list = Defaults.get_grub_efi_modules(multiboot=self.xen_guest)
-        module_path = self._get_efi_modules_path(lookup_path)
+        module_path = self._get_efi_modules_path(self.root_dir)
         if os.path.exists(module_path + '/linuxefi.mod'):
             module_list.append('linuxefi')
-        Command.run(
+        mkimage_call = Command.run(
             [
-                self._get_grub2_mkimage_tool() or 'grub2-mkimage',
+                'chroot', self.root_dir,
+                os.path.basename(
+                    self._get_grub2_mkimage_tool()
+                ) or 'grub2-mkimage',
                 '-O', Defaults.get_efi_module_directory_name(self.arch),
-                '-o', self._get_efi_image_name(),
-                '-c', early_boot_script,
+                '-o', ''.join(
+                    [
+                        '/boot/efi/EFI/BOOT/',
+                        Defaults.get_efi_image_name(self.arch)
+                    ]
+                ),
+                '-c', '/boot/efi/EFI/BOOT/earlyboot.cfg',
                 '-p', self.get_boot_path() + '/' + self.boot_directory_name,
-                '-d', module_path
+                '-d', module_path.replace(self.root_dir, '')
             ] + module_list
         )
+        log.debug(mkimage_call.output)
 
     def _create_efi_config_search(self, uuid=None, mbrid=None):
         efi_boot_config = self.efi_boot_path + '/grub.cfg'
@@ -846,16 +858,39 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         self._create_early_boot_script_for_mbrid_search(
             early_boot_script, mbrid
         )
-        Command.run(
+        shutil.copy(
+            early_boot_script, os.sep.join(
+                [self.root_dir, 'boot', self.boot_directory_name]
+            )
+        )
+        mkimage_call = Command.run(
             [
-                self._get_grub2_mkimage_tool() or 'grub2-mkimage',
+                'chroot', self.root_dir,
+                os.path.basename(
+                    self._get_grub2_mkimage_tool()
+                ) or 'grub2-mkimage',
                 '-O', Defaults.get_bios_module_directory_name(),
-                '-o', self._get_bios_image_name(lookup_path),
-                '-c', early_boot_script,
-                '-p', self.get_boot_path() + '/' + self.boot_directory_name,
-                '-d', self._get_bios_modules_path(lookup_path)
+                '-o', self._get_bios_image_name(os.sep),
+                '-c', early_boot_script.replace(self.boot_dir, ''),
+                '-p', os.sep.join(
+                    [self.get_boot_path(), self.boot_directory_name]
+                ),
+                '-d', self._get_bios_modules_path(os.sep)
             ] + Defaults.get_grub_bios_modules(multiboot=self.xen_guest)
         )
+        log.debug(mkimage_call.output)
+
+        # The following copy is needed for images that uses the
+        # custom boot image feature. In this mode the boot image(initrd)
+        # root tree is different from the system root tree
+        # and it's needed to copy the generated grub image there
+        bios_image_root_file = self._get_bios_image_name(self.root_dir)
+        bios_image_media_file = bios_image_root_file.replace(
+            self.root_dir, lookup_path
+        )
+        if (bios_image_root_file != bios_image_media_file):
+            Path.create(os.path.dirname(bios_image_media_file))
+            shutil.copy(bios_image_root_file, bios_image_media_file)
 
     def _create_early_boot_script_for_uuid_search(self, filename, uuid):
         with open(filename, 'w') as early_boot:
@@ -916,8 +951,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
 
     def _get_grub2_mkimage_tool(self):
         for grub_mkimage_tool in ['grub2-mkimage', 'grub-mkimage']:
-            if Path.which(grub_mkimage_tool):
-                return grub_mkimage_tool
+            grub_mkimage_file_path = Path.which(
+                grub_mkimage_tool, root_dir=self.root_dir
+            )
+            if grub_mkimage_file_path:
+                return grub_mkimage_file_path
 
     def _get_grub2_mkconfig_tool(self):
         for grub_mkconfig_tool in ['grub2-mkconfig', 'grub-mkconfig']:
