@@ -37,7 +37,7 @@ class FileSystem(metaclass=ABCMeta):
     """
     @abstractmethod
     def __init__(self) -> None:
-        return None
+        return None  # pragma: no cover
 
     @staticmethod
     def new(
