@@ -267,7 +267,7 @@ class XMLState:
                 return check_signatures[0]
         return False
 
-    def get_package_manager(self) -> Optional[str]:
+    def get_package_manager(self) -> str:
         """
         Get configured package manager from selected preferences section
 
@@ -279,7 +279,7 @@ class XMLState:
             package_manager = preferences.get_packagemanager()
             if package_manager:
                 return package_manager[0]
-        return None
+        return Defaults.get_default_package_manager()
 
     def get_packages_sections(self, section_types: List) -> List:
         """
@@ -1012,6 +1012,25 @@ class XMLState:
             return container_config_sections[0]
         return None
 
+    def get_installmedia_initrd_modules(self, action: str) -> List[str]:
+        """
+        Gets the list of modules to append in installation initrds
+
+        :return: a list of dracut module names
+
+        :rtype: list
+        """
+        modules = []
+        installmedia = self.build_type.get_installmedia()
+        if not installmedia:
+            return modules
+        initrd_sections = installmedia[0].get_initrd()
+        for initrd_section in initrd_sections:
+            if initrd_section.get_action() == action:
+                for module in initrd_section.get_dracut():
+                    modules.append(module.get_module())
+        return modules
+
     def get_build_type_size(
         self, include_unpartitioned: bool = False
     ) -> Optional[size_type]:
