@@ -97,6 +97,11 @@ class TestXMLState:
     def test_get_package_manager(self):
         assert self.state.get_package_manager() == 'zypper'
 
+    @patch('kiwi.xml_state.XMLState.get_preferences_sections')
+    def test_get_default_package_manager(self, mock_preferences):
+        mock_preferences.return_value = []
+        assert self.state.get_package_manager() == 'dnf'
+
     def test_get_image_version(self):
         assert self.state.get_image_version() == '1.13.2'
 
@@ -978,3 +983,11 @@ class TestXMLState:
         mock_bootloader.return_value = [self.bootloader]
         assert self.state.get_build_type_bootloader_targettype() == \
             'some-target'
+
+    def test_get_installintrd_modules(self):
+        self.state.get_installmedia_initrd_modules('add') == ['network-legacy']
+        self.state.get_installmedia_initrd_modules('set') == []
+        self.state.get_installmedia_initrd_modules('omit') == []
+        xml_data = self.description.load()
+        state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
+        state.get_installmedia_initrd_modules('add') == []
